@@ -14,5 +14,7 @@ sed -ri 's/(<(token|exception|suggestion|match|disambig|feature|phraseref|wd)[^>
 sed -ri 's/[ \t]+\r?$/\r/' $@
 sed -ri 's/" >/">/' $@
 sed -ri 's/ \/>/\/>/' $@
+sed -ri 's/\.\.\.<\/example>/…<\/example>/' $@
+sed -ri 's/<example>\.\.\./<example>…/' $@
 
 echo $@' indented'
